# Holmes Dust Trail Coordinate Calculator for Python Skyfield for Utah. Trail position July 2024.
# Copyright (C) Markku Nissinen, Maria Gritsevich 4.9.2023

from skyfield import api

from skyfield.positionlib import Barycentric

from skyfield.vectorlib import VectorFunction

from skyfield.api import load


# SEPTEMBER 2023 START

# NORTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.369543282088844, 1.387828012275105, 1.4754982288559364],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.369543282088844, 1.387828012275105, 1.4754982288559364],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.369543282088844, 1.387828012275105, 1.4754982288559364],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftNorthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.394792773450881, 1.3598222897029881, 1.4568947983391431],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.394792773450881, 1.3598222897029881, 1.4568947983391431],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.394792773450881, 1.3598222897029881, 1.4568947983391431],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleNorthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4070992706709209, 1.3451993294825697, 1.4475633019173972],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4070992706709209, 1.3451993294825697, 1.4475633019173972],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4070992706709209, 1.3451993294825697, 1.4475633019173972],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightNorthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4191272064607643, 1.3312484102416724, 1.4387313491607006],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4191272064607643, 1.3312484102416724, 1.4387313491607006],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4191272064607643, 1.3312484102416724, 1.4387313491607006],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightNorthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4370370641888135, 1.3116253258698651, 1.425648694317014],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4370370641888135, 1.3116253258698651, 1.425648694317014],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4370370641888135, 1.3116253258698651, 1.425648694317014],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# NORTHERN SKY STOP

# SOUTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftSouthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.444232090614947, -2.489647384132119, -2.6273307970472826],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.444232090614947, -2.489647384132119, -2.6273307970472826],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.444232090614947, -2.489647384132119, -2.6273307970472826],           # FarLeft point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftSouthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.5733605815715475, -2.5002126450105333, -2.6725124048657123],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.5733605815715475, -2.5002126450105333, -2.6725124048657123],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.5733605815715475, -2.5002126450105333, -2.6725124048657123],           # Left point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleSouthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.55183503327285, -2.4007485156603185, -2.5847692292413798],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.55183503327285, -2.4007485156603185, -2.5847692292413798],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.55183503327285, -2.4007485156603185, -2.5847692292413798],           # Middle point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightSouthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.993117122246379, -2.583271385872959, -2.838371688968011],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.993117122246379, -2.583271385872959, -2.838371688968011],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.993117122246379, -2.583271385872959, -2.838371688968011],           # Right point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightSouthernNode_September2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.796828037061145, -2.383232744216772, -2.6279934768017297],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.796828037061145, -2.383232744216772, -2.6279934768017297],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.796828037061145, -2.383232744216772, -2.6279934768017297],           # FarRight point of dust trail September 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# SOUTHERN SKY STOP

# SEPTEMBER 2023 STOP



# NOVEMBER 2023 START

# NORTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3756043295552396, 1.3795238558923175, 1.4706988607127234],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3756043295552396, 1.3795238558923175, 1.4706988607127234],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3756043295552396, 1.3795238558923175, 1.4706988607127234],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftNorthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.390747362014189, 1.3621825726282766, 1.459107687834096],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.390747362014189, 1.3621825726282766, 1.459107687834096],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.390747362014189, 1.3621825726282766, 1.459107687834096],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleNorthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.410740793901225, 1.339165813904964, 1.4436763415684999],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.410740793901225, 1.339165813904964, 1.4436763415684999],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.410740793901225, 1.339165813904964, 1.4436763415684999],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightNorthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4269378867170837, 1.3207465953556998, 1.4325662941084458],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4269378867170837, 1.3207465953556998, 1.4325662941084458],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4269378867170837, 1.3207465953556998, 1.4325662941084458],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightNorthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4448491806046209, 1.2968119507319293, 1.417991692456905],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4448491806046209, 1.2968119507319293, 1.417991692456905],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4448491806046209, 1.2968119507319293, 1.417991692456905],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# NORTHERN SKY STOP

# SOUTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftSouthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.4029341799711323, -2.655170619139324, -2.7552569588087454],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.4029341799711323, -2.655170619139324, -2.7552569588087454],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.4029341799711323, -2.655170619139324, -2.7552569588087454],           # FarLeft point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftSouthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.5284924597422846, -2.576767798473582, -2.7272765385616546],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.5284924597422846, -2.576767798473582, -2.7272765385616546],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.5284924597422846, -2.576767798473582, -2.7272765385616546],           # Left point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleSouthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.660026073032623, -2.5045876736561428, -2.695626086309426],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.660026073032623, -2.5045876736561428, -2.695626086309426],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.660026073032623, -2.5045876736561428, -2.695626086309426],           # Middle point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightSouthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-3.0320038265581744, -2.539155627265674, -2.816784701401427],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-3.0320038265581744, -2.539155627265674, -2.816784701401427],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-3.0320038265581744, -2.539155627265674, -2.816784701401427],           # Right point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightSouthernNode_November2023(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-3.2241244423224074, -2.471048561171835, -2.7865277935697406],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-3.2241244423224074, -2.471048561171835, -2.7865277935697406],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-3.2241244423224074, -2.471048561171835, -2.7865277935697406],           # FarRight point of dust trail November 2023

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# SOUTHERN SKY STOP

# NOVEMBER 2023 STOP


# JANUARY 2024 START

# NORTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3722726746358183, 1.381319578447682, 1.4687372681509583],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3722726746358183, 1.381319578447682, 1.4687372681509583],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3722726746358183, 1.381319578447682, 1.4687372681509583],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftNorthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3891278433725425, 1.3636237970718206, 1.4585384620190027],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3891278433725425, 1.3636237970718206, 1.4585384620190027],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3891278433725425, 1.3636237970718206, 1.4585384620190027],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleNorthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4002049103016008, 1.3504179850356588, 1.4508159715602584],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4002049103016008, 1.3504179850356588, 1.4508159715602584],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4002049103016008, 1.3504179850356588, 1.4508159715602584],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightNorthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.41419564895703, 1.3334485790656385, 1.440158801140425],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.41419564895703, 1.3334485790656385, 1.440158801140425],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.41419564895703, 1.3334485790656385, 1.440158801140425],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightNorthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.426965176028763, 1.3188072531504162, 1.4311473953880325],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.426965176028763, 1.3188072531504162, 1.4311473953880325],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.426965176028763, 1.3188072531504162, 1.4311473953880325],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# NORTHERN SKY STOP

# SOUTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftSouthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.2710456293633823, -2.483527723454546, -2.590901052591679],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.2710456293633823, -2.483527723454546, -2.590901052591679],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.2710456293633823, -2.483527723454546, -2.590901052591679],           # FarLeft point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftSouthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.3700294133653594, -2.4635303346323796, -2.5939241318163644],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.3700294133653594, -2.4635303346323796, -2.5939241318163644],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.3700294133653594, -2.4635303346323796, -2.5939241318163644],           # Left point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleSouthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.7326134873506636, -2.4800925104416978, -2.6948471676374908],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.7326134873506636, -2.4800925104416978, -2.6948471676374908],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.7326134873506636, -2.4800925104416978, -2.6948471676374908],           # Middle point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightSouthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.9097375952529023, -2.5676408434067723, -2.8032335712243497],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.9097375952529023, -2.5676408434067723, -2.8032335712243497],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.9097375952529023, -2.5676408434067723, -2.8032335712243497],           # Right point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightSouthernNode_January2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-3.0015056301742042, -2.547631102506582, -2.8059299332203107],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-3.0015056301742042, -2.547631102506582, -2.8059299332203107],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-3.0015056301742042, -2.547631102506582, -2.8059299332203107],           # FarRight point of dust trail January 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# SOUTHERN SKY STOP

# JANUARY 2024 STOP



# JULY 2024 START

# NORTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.31402825732349, 1.443902572380403, 1.5089746752119824],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.31402825732349, 1.443902572380403, 1.5089746752119824],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.31402825732349, 1.443902572380403, 1.5089746752119824],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftNorthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3585985516640924, 1.3983025143801173, 1.4823447897677122],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3585985516640924, 1.3983025143801173, 1.4823447897677122],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3585985516640924, 1.3983025143801173, 1.4823447897677122],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleNorthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4007014957253752, 1.3473230759519181, 1.4483544040964587],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4007014957253752, 1.3473230759519181, 1.4483544040964587],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4007014957253752, 1.3473230759519181, 1.4483544040964587],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightNorthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4186467632281403, 1.326516815212094, 1.435126189264496],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4186467632281403, 1.326516815212094, 1.435126189264496],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4186467632281403, 1.326516815212094, 1.435126189264496],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightNorthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4424786760886628, 1.2969708524837529, 1.4183672202283764],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4424786760886628, 1.2969708524837529, 1.4183672202283764],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4424786760886628, 1.2969708524837529, 1.4183672202283764],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# NORTHERN SKY STOP

# SOUTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftSouthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.9023258395279057, -2.5798657289328593, -2.8178277581984967],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.9023258395279057, -2.5798657289328593, -2.8178277581984967],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.9023258395279057, -2.5798657289328593, -2.8178277581984967],           # FarLeft point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftSouthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.8544655057644888, -2.470275211096017, -2.714731746581166],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.8544655057644888, -2.470275211096017, -2.714731746581166],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.8544655057644888, -2.470275211096017, -2.714731746581166],           # Left point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleSouthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.9455597684959307, -2.4544452589292556, -2.7159551608796284],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.9455597684959307, -2.4544452589292556, -2.7159551608796284],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.9455597684959307, -2.4544452589292556, -2.7159551608796284],           # Middle point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightSouthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-3.1901633655209376, -2.538150138430883, -2.8399655188965256],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-3.1901633655209376, -2.538150138430883, -2.8399655188965256],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-3.1901633655209376, -2.538150138430883, -2.8399655188965256],           # Right point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightSouthernNode_July2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-3.1361288025629244, -2.44316690213909, -2.757739880315218],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-3.1361288025629244, -2.44316690213909, -2.757739880315218],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-3.1361288025629244, -2.44316690213909, -2.757739880315218],           # FarRight point of dust trail July 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# SOUTHERN SKY STOP

# JULY 2024 STOP




# OCTOBER 2024 START

# NORTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.2938859045088626, 1.4690557841970049, 1.5275224557867322],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.2938859045088626, 1.4690557841970049, 1.5275224557867322],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.2938859045088626, 1.4690557841970049, 1.5275224557867322],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftNorthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3132665259389265, 1.4497843453200308, 1.5114113677095575],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3132665259389265, 1.4497843453200308, 1.5114113677095575],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3132665259389265, 1.4497843453200308, 1.5114113677095575],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleNorthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.3547378394266216, 1.3989778689604506, 1.4787866860448848],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.3547378394266216, 1.3989778689604506, 1.4787866860448848],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.3547378394266216, 1.3989778689604506, 1.4787866860448848],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightNorthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4231976855012751, 1.321184347278068, 1.4319896948491377],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4231976855012751, 1.321184347278068, 1.4319896948491377],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4231976855012751, 1.321184347278068, 1.4319896948491377],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightNorthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [1.4298711662595363, 1.313244555309976, 1.426557652905995],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [1.4298711662595363, 1.313244555309976, 1.426557652905995],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [1.4298711662595363, 1.313244555309976, 1.426557652905995],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# NORTHERN SKY STOP

# SOUTHERN SKY START

class Holmes_Dust_Trail_Stationary_FarLeftSouthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.4315114900519283, -2.6954787760961274, -2.7981372422157382],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.4315114900519283, -2.6954787760961274, -2.7981372422157382],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.4315114900519283, -2.6954787760961274, -2.7981372422157382],           # FarLeft point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_LeftSouthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.630766470185197, -2.748323098302526, -2.88275452457729],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.630766470185197, -2.748323098302526, -2.88275452457729],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.630766470185197, -2.748323098302526, -2.88275452457729],           # Left point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_MiddleSouthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.6436497712847395, -2.686785821795672, -2.8353255017385615],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.6436497712847395, -2.686785821795672, -2.8353255017385615],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.6436497712847395, -2.686785821795672, -2.8353255017385615],           # Middle point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_RightSouthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.6982729509065124, -2.5897552245422335, -2.7723185434670277],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.6982729509065124, -2.5897552245422335, -2.7723185434670277],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.6982729509065124, -2.5897552245422335, -2.7723185434670277],           # Right point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

class Holmes_Dust_Trail_Stationary_FarRightSouthernNode_October2024(VectorFunction):

    center = 0

    def at(self, t):

        b = Barycentric(

            [-2.8732428810508424, -2.660035171300858, -2.871052459829105],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            t=t,                    # time

            target=self,            # Holmes_Dust_Trail is the target body

        )

        return b

    def _at(self, t):

        b = (

            [-2.8732428810508424, -2.660035171300858, -2.871052459829105],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b


    def target(self, t):

        b = (

            [-2.8732428810508424, -2.660035171300858, -2.871052459829105],           # FarRight point of dust trail October 2024

            [0, 0, 0],  # Stationary point

            0,                    # bcrs position

            "Holmes_dust_trail"            # Holmes_Dust_Trail is the target body

        )

        return b

# SOUTHERN SKY STOP

# OCTOBER 2024 STOP


ts = load.timescale()



planets = load('de421.bsp')

earth = planets['earth']



from skyfield.api import N,S,E,W, wgs84



# Altitude and azimuth in the sky of a

# specific geographic location

Kouvola = earth + wgs84.latlon(60.8666700 * N, 26.7000000 * E, elevation_m=81)

Utah = earth + wgs84.latlon(37.7378 * N, 113.6975 * W, elevation_m=1570)

SidingSpring = earth + wgs84.latlon(31.273333 * S, 149.064444 * E, elevation_m=1122)


# Utah JULY 2024 START

#Utah FarLeft JULY 2024
t = ts.utc(2023, 9, 1, 0)

for _ in range(16000):

    t = t+(1/24)
        
    astro = Utah.at(t).observe(Holmes_Dust_Trail_Stationary_FarLeftNorthernNode_July2024())
    
    app = astro.apparent()    
    
    # alt, az, distance = app.altaz()
    
    alt, az, distance = app.altaz(temperature_C=22.0,
    
                                  pressure_mbar=1005.0)
    
    ra, dec, astro_distance = app.radec()
        
    #print(distance)

    print('Utah_FarLeft_July2024', end = ' ')

    print('', t.utc_jpl(), end = ' ')

    print('JD: {:.10f}'.format(t.ut1), end = ' ')

    print('RADEC: {:.8f}'.format(ra.hours*15), end = ' ')
        
    print('DeclDEC: {:.8f}'.format(dec.degrees), end = ' ')

    print('RA:', ra, end = ' ')
    
    print('Decl:', dec, end = ' ')

    print('Alt:', alt.dstr(), end = ' ')
    
    print('Az:', az.dstr(), end = ' ')
    
    print('Distance:', astro_distance)

#Utah Left JULY 2024
t = ts.utc(2023, 9, 1, 0)

for _ in range(16000):

    t = t+(1/24)
        
    astro = Utah.at(t).observe(Holmes_Dust_Trail_Stationary_LeftNorthernNode_July2024())
    
    app = astro.apparent()    
    
    # alt, az, distance = app.altaz()
    
    alt, az, distance = app.altaz(temperature_C=22.0,
    
                                  pressure_mbar=1005.0)
    
    ra, dec, astro_distance = app.radec()
        
    #print(distance)

    print('Utah_Left_July2024', end = ' ')

    print('', t.utc_jpl(), end = ' ')

    print('JD: {:.10f}'.format(t.ut1), end = ' ')

    print('RADEC: {:.8f}'.format(ra.hours*15), end = ' ')
        
    print('DeclDEC: {:.8f}'.format(dec.degrees), end = ' ')

    print('RA:', ra, end = ' ')
    
    print('Decl:', dec, end = ' ')

    print('Alt:', alt.dstr(), end = ' ')
    
    print('Az:', az.dstr(), end = ' ')
    
    print('Distance:', astro_distance)

#Utah Middle JULY 2024
t = ts.utc(2023, 9, 1, 0)

for _ in range(16000):

    t = t+(1/24)
        
    astro = Utah.at(t).observe(Holmes_Dust_Trail_Stationary_MiddleNorthernNode_July2024())
    
    app = astro.apparent()    
    
    # alt, az, distance = app.altaz()
    
    alt, az, distance = app.altaz(temperature_C=22.0,
    
                                  pressure_mbar=1005.0)
    
    ra, dec, astro_distance = app.radec()
        
    #print(distance)

    print('Utah_Middle_July2024', end = ' ')

    print('', t.utc_jpl(), end = ' ')

    print('JD: {:.10f}'.format(t.ut1), end = ' ')

    print('RADEC: {:.8f}'.format(ra.hours*15), end = ' ')
        
    print('DeclDEC: {:.8f}'.format(dec.degrees), end = ' ')

    print('RA:', ra, end = ' ')
    
    print('Decl:', dec, end = ' ')

    print('Alt:', alt.dstr(), end = ' ')
    
    print('Az:', az.dstr(), end = ' ')
    
    print('Distance:', astro_distance)

#Utah Right JULY 2024
t = ts.utc(2023, 9, 1, 0)

for _ in range(16000):

    t = t+(1/24)
        
    astro = Utah.at(t).observe(Holmes_Dust_Trail_Stationary_RightNorthernNode_July2024())
    
    app = astro.apparent()    
    
    # alt, az, distance = app.altaz()
    
    alt, az, distance = app.altaz(temperature_C=22.0,
    
                                  pressure_mbar=1005.0)
    
    ra, dec, astro_distance = app.radec()
        
    #print(distance)

    print('Utah_Right_July2024', end = ' ')

    print('', t.utc_jpl(), end = ' ')

    print('JD: {:.10f}'.format(t.ut1), end = ' ')

    print('RADEC: {:.8f}'.format(ra.hours*15), end = ' ')
        
    print('DeclDEC: {:.8f}'.format(dec.degrees), end = ' ')

    print('RA:', ra, end = ' ')
    
    print('Decl:', dec, end = ' ')

    print('Alt:', alt.dstr(), end = ' ')
    
    print('Az:', az.dstr(), end = ' ')
    
    print('Distance:', astro_distance)

#Utah FarRight JULY 2024
t = ts.utc(2023, 9, 1, 0)

for _ in range(16000):

    t = t+(1/24)
        
    astro = Utah.at(t).observe(Holmes_Dust_Trail_Stationary_FarRightNorthernNode_July2024())
    
    app = astro.apparent()    
    
    # alt, az, distance = app.altaz()
    
    alt, az, distance = app.altaz(temperature_C=22.0,
    
                                  pressure_mbar=1005.0)
    
    ra, dec, astro_distance = app.radec()
        
    #print(distance)

    print('Utah_FarRight_July2024', end = ' ')

    print('', t.utc_jpl(), end = ' ')

    print('JD: {:.10f}'.format(t.ut1), end = ' ')

    print('RADEC: {:.8f}'.format(ra.hours*15), end = ' ')
        
    print('DeclDEC: {:.8f}'.format(dec.degrees), end = ' ')

    print('RA:', ra, end = ' ')
    
    print('Decl:', dec, end = ' ')

    print('Alt:', alt.dstr(), end = ' ')
    
    print('Az:', az.dstr(), end = ' ')
    
    print('Distance:', astro_distance)

# Utah JULY 2024 END
